@@ -1,7 +1,7 @@
 package Test2::MojoX;
 use Mojo::Base -base;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 ## "Amy: He knows when you are sleeping.
 ##  Professor: He knows when you're on the can.
@@ -565,7 +565,7 @@ sub _wait {
 
 =head1 NAME
 
-Test2::Mojo - Testing Mojo
+Test2::MojoX - Testing Mojo
 
 =head1 SYNOPSIS
 
